@@ -1,3 +1,4 @@
+# nocov start
 ## package imports
 #' @importFrom utils head head.matrix tail tail.matrix
 #' @importFrom stats setNames na.omit prop.test binom.test relevel quantile
@@ -21,7 +22,7 @@ NULL
 #' @param colwidths numeric vector. Column widths for use with vertical pagination. Currently ignored.
 #' @param obj ANY. The object for the accessor to access or modify
 #' @param x An object
-#' @param \dots Passed on to metthods or tabulation functions.
+#' @param \dots Passed on to methods or tabulation functions.
 #' @param value The new value
 #' @param object The object to modify in-place
 #' @param verbose logical(1). Should extra debugging messages be shown. Defaults to \code{FALSE}.
@@ -32,11 +33,14 @@ NULL
 # #' @param visible_label logical(1). Should the \emph{split} label be visible in the resulting table.
 #' @param cvar character(1). The variable, if any, which the content function should accept. Defaults to NA.
 #' @param topleft character. Override values for the "top left" material to be displayed during printing.
+#' @param page_prefix character(1). Prefix, to be appended with the split value, when forcing pagination between the children of this split/table
+
+
 #' @return NULL (this is an argument template dummy function)
 #' @rdname gen_args
 gen_args <- function(df, alt_counts_df, spl, pos, tt, tr, verbose, colwidths, obj, x,
                      value, object, path, label, label_pos, # visible_label,
-                     cvar, topleft, ...) NULL
+                     cvar, topleft, page_prefix,  ...) NULL
 
 
 
@@ -53,8 +57,9 @@ gen_args <- function(df, alt_counts_df, spl, pos, tt, tr, verbose, colwidths, ob
 #' @param varnames character vector. Names for \code{vars} which will appear in pathing. When \code{vars} are all unique this will be the variable names. If not, these will be variable names with suffixes as necessary to enforce uniqueness.
 #' @param split_format FormatSpec. Default format associated with the split being created.
 #' @param split_label string. Label string to be associated with the table generated by the split. Not to be confused with labels assigned to each child (which are based on the data and type of split during tabulation).
-#' @param nested boolean, Add this as a new top-level split  (defining a new subtable directly under root). Defaults to \code{FALSE}
+#' @param nested boolean. Should this layout instruction be applied within the existing layout structure \emph{if possible} (`TRUE`, the default) or as a new top-level element (`FALSE). Ignored if it would nest a split underneath analyses, which is not allowed.
 #' @param format FormatSpec. Format associated with this split. Formats can be declared via strings (\code{"xx.x"}) or function. In cases such as \code{analyze} calls, they can character vectors or lists of functions.
+#' @param align character(1). Alignment the value should be rendered with. See \code{\link{rtables_aligns}} for currently supported alignments.
 #' @param cfun list/function/NULL. tabulation function(s) for creating content rows. Must accept \code{x} or \code{df} as first parameter. Must accept \code{labelstr} as the second argument. Can optionally accept all optional arguments accepted by analysis functions. See \code{\link{analyze}}.
 #' @param cformat format spec. Format for content rows
 #' @param split_fun function/NULL. custom splitting function See \code{\link{custom_split_funs}}
@@ -76,6 +81,7 @@ gen_args <- function(df, alt_counts_df, spl, pos, tt, tr, verbose, colwidths, ob
 #' @param indent_mod numeric. Modifier for the default indent position for the structure created by this function(subtable, content table, or row) \emph{and all of that structure's children}. Defaults to 0, which corresponds to the unmodified default behavior.
 #' @param show_labels character(1). Should the variable labels for corresponding to the variable(s) in \code{vars} be visible in the resulting table.
 #' @param table_names character. Names for the tables representing each atomic analysis. Defaults to \code{var}.
+#' @param page_by logical(1). Should pagination be forced between different children resulting form this split.
 #' @inheritParams gen_args
 #' @inherit gen_args return
 #' @family conventions
@@ -86,7 +92,7 @@ lyt_args <- function( lyt, var, vars, label, labels_var, varlabels, varnames, sp
                      cuts, cutlabels, cutfun, cutlabelfun, cumulative,
                      indent_mod, show_labels, label_pos, #visible_label,
                      var_labels, cvar,
-                     table_names, topleft) NULL
+                     table_names, topleft, align, page_by, page_prefix) NULL
 
 
 #' Constructor Arg Conventions
@@ -111,12 +117,12 @@ lyt_args <- function( lyt, var, vars, label, labels_var, varlabels, varnames, sp
 #' @param main_footer character. Main global (non-referential) footer materials.
 #' @param prov_footer character. Provenance-related global footer materials. Generally should not be modified by hand.
 #' @param footnotes list or NULL. Referential footnotes to be applied at current level
-
+#' @param page_title character. Page specific title(s).
 #' @rdname constr_args
 constr_args <- function(kids, cont, lev, iscontent, cinfo, labelrow, vals, cspan, label_pos, #visible_label,
                         cindent_mod, cvar, label, cextra_args, child_names,
                         title, subtitles, main_footer, prov_footer,
-                        footnotes) NULL
+                        footnotes, page_title, page_prefix) NULL
 
 #' Compatability Arg Conventions
 #' @name compat_args
@@ -154,44 +160,5 @@ compat_args <- function(.lst, FUN, col_by, row_by, row.name, format, indent, col
 #' @param first logical(1). Should the created split level be placed first in the levels (\code{TRUE}) or last (\code{FALSE}, the default).
 #'
 sf_args <- function(trim, label, first) NULL
-## data
 
-#' DM data
-#'
-#' @format rds (data.frame)
-"DM"
-
-
-
-#' Simulated CDISC Alike Data for Examples
-#'
-#' @format rds (data.frame)
-#' @rdname cdisc_data
-"ex_adsl"
-
-#' @rdname cdisc_data
-"ex_adae"
-
-#' @rdname cdisc_data
-"ex_adaette"
-
-#' @rdname cdisc_data
-"ex_adtte"
-
-#' @rdname cdisc_data
-"ex_adcm"
-
-#' @rdname cdisc_data
-"ex_adlb"
-
-#' @rdname cdisc_data
-"ex_admh"
-
-#' @rdname cdisc_data
-"ex_adqs"
-
-#' @rdname cdisc_data
-"ex_adrs"
-
-#' @rdname cdisc_data
-"ex_advs"
+# nocov end
