@@ -22,7 +22,6 @@ test_that("complex layout works", {
     lyt <- make_big_lyt()
 
     ## ensure print method works for predata layout
-    print(lyt)
     tab <- build_table(lyt, rawdat)
     tab_str <- toString(tab)
     ## XXX TODO this assumes we want no var label on VAR3 subtable
@@ -70,6 +69,24 @@ tab2 = build_table(thing2, rawdat)
     tab3
 })
 
+test_that("Nested splits in column space work", {
+
+    dat2 <- subset(ex_adsl, SEX %in% c("M", "F"))
+    tbl2 <- basic_table() %>%
+        split_cols_by("ARM") %>%
+        split_cols_by("SEX", split_fun = drop_split_levels) %>%
+        analyze(c("AGE", "STRATA1")) %>%
+        build_table(dat2)
+
+    mf <- matrix_form(tbl2)
+    expect_identical(unname(mf$strings[1, , drop = TRUE]),
+                     c("", "A: Drug X", "A: Drug X", "B: Placebo", "B: Placebo",
+                       "C: Combination", "C: Combination"))
+    expect_identical(unname(mf$display[1, , drop = TRUE]),
+                     c(TRUE, TRUE, FALSE, TRUE, FALSE, TRUE, FALSE))
+
+})
+
 
 test_that("labelkids parameter works", {
     yeslabellyt <- basic_table() %>% split_cols_by("ARM") %>%
@@ -254,24 +271,32 @@ test_that("missing vars caught", {
     analyze("AGE", "Age Analysis", afun = function(x) list(mean = mean(x),
                                                                     median = median(x)), format = "xx.xx")
 
-    expect_error(build_table(misscol, rawdat))
+    expect_error(build_table(misscol, rawdat), "Split variable [[]SX[]] not found in data being tabulated.")
 
     missrsplit =  basic_table() %>% split_cols_by("ARM") %>%
-    split_cols_by("SEX", "Gender") %>%
-    split_rows_by("RACER", "ethn") %>%
+    split_cols_by("SEX", "gend_label") %>%
+    split_rows_by("RACER", "ethn_label") %>%
     analyze("AGE", "Age Analysis", afun = function(x) list(mean = mean(x),
                                                            median = median(x)), format = "xx.xx")
 
-    expect_error(build_table(missrsplit, rawdat))
+    expect_error(build_table(missrsplit, rawdat), "Split variable [[]RACER[]] not found in data being tabulated.")
+
+    missrsplit =  basic_table() %>% split_cols_by("ARM") %>%
+    split_cols_by("SEX", "gend_label") %>%
+    split_rows_by("RACE", "ethnNA_label") %>%
+    analyze("AGE", "Age Analysis", afun = function(x) list(mean = mean(x),
+                                                           median = median(x)), format = "xx.xx")
+
+    expect_error(build_table(missrsplit, rawdat), "Value label variable [[]ethnNA_label[]] not found in data being tabulated.")
 
     missavar =  basic_table() %>% split_cols_by("ARM") %>%
-    split_cols_by("SEX", "Gender") %>%
-    split_rows_by("RACE", "ethn") %>%
+    split_cols_by("SEX", labels_var = "gend_label") %>%
+    split_rows_by("RACE", labels_var = "ethn_label") %>%
     analyze("AGGE", "Age Analysis", afun = function(x) list(mean = mean(x),
                                                                     median = median(x)), format = "xx.xx")
 
-    expect_error(build_table(missavar, rawdat))
-    })
+    expect_error(build_table(missavar, rawdat), ".*variable[(]s[)] [[]AGGE[]] not present in data. [(]AnalyzeVarSplit[)].*")
+})
 
 
 
@@ -623,8 +648,8 @@ test_that("analyze_colvars works generally", {
     ## this broke before due to formatting missmatches
     toString(tab4)
     rws4 <- collect_leaves(tab4, TRUE, TRUE)
-    expect_identical(rtables:::obj_format(rws4[[1]]), "xx (xx.x%)")
-    expect_identical(rtables:::obj_format(rws4[[2]]), NULL)
+    expect_identical(obj_format(rws4[[1]]), "xx (xx.x%)")
+    expect_identical(obj_format(rws4[[2]]), NULL)
 
     l5 <- basic_table() %>%
         split_cols_by("ARM") %>%
@@ -781,12 +806,160 @@ test_that(".spl_context works in content and analysis functions", {
                                `[[`, 2L)))
 })
 
+test_that("cut functions work", {
 
-test_that("deprecated things are still there and work kinda", {
+    ctnames <- c("young", "medium", "old")
+    ## split_cols_by_cuts
+    l <- basic_table() %>%
+        split_cols_by("ARM") %>%
+        split_cols_by_cuts("AGE", split_label = "Age",
+                           cuts = c(0, 25, 35, 1000),
+                           cutlabels = ctnames) %>%
+        analyze(c("BMRKR2", "STRATA2")) %>%
+        append_topleft("counts")
+
+    tbl <- build_table(l, ex_adsl)
+
+    chkvals <- cell_values(tbl, c("BMRKR2", "LOW"), c("ARM", "A: Drug X"))
+    expect_identical(unname(unlist(chkvals)),
+                     c(nrow(subset(ex_adsl, ARM == "A: Drug X" & BMRKR2 == "LOW" & AGE <= 25)),
+                       nrow(subset(ex_adsl, ARM == "A: Drug X" & BMRKR2 == "LOW" & AGE > 25 & AGE <= 35)),
+                       nrow(subset(ex_adsl, ARM == "A: Drug X" & BMRKR2 == "LOW" & AGE > 35))))
+
+    mf <- matrix_form(tbl)
+    expect_identical(mf$strings[2,, drop = TRUE],
+                     c("", rep(ctnames, 3)))
+
+    lcm <- basic_table() %>%
+        split_cols_by("ARM") %>%
+        split_cols_by_cuts("AGE", split_label = "Age",
+                           cuts = c(0, 25, 35, 1000),
+                           cutlabels = c("young", "young+medium", "all"),
+                           cumulative = TRUE) %>%
+        analyze(c("BMRKR2", "STRATA2")) %>%
+        append_topleft("counts")
+
+    tblcm <- build_table(lcm, ex_adsl)
+
+    medpth <- c("BMRKR2", "MEDIUM")
+    bpth <- c("ARM", "B: Placebo")
+    expect_identical(cumsum(unname(unlist(cell_values(tbl, medpth, bpth)))),
+                     unname(unlist(cell_values(tblcm, medpth, bpth))))
+    ## split_rows_by_cuts
+    l2 <- basic_table() %>%
+        split_cols_by("ARM") %>%
+        split_rows_by_cuts("AGE", split_label = "Age",
+                           cuts = c(0, 25, 35, 1000),
+                           cutlabels = ctnames) %>%
+        analyze("BMRKR2") %>%
+        append_topleft("counts")
+
+
+    tbl2 <- build_table(l2, ex_adsl)
+
+    mf2 <- matrix_form(tbl2)
+
+    expect_identical(mf2$strings[c(2, 6, 10), 1,drop = TRUE],
+                     ctnames)
+
+
+    l2cm <- basic_table() %>%
+        split_cols_by("ARM") %>%
+        split_rows_by_cuts("AGE", split_label = "Age",
+                           cuts = c(0, 25, 35, 1000),
+                           cutlabels = ctnames, cumulative = TRUE) %>%
+        analyze("BMRKR2") %>%
+        append_topleft("counts")
+
+
+    tbl2cm <- build_table(l2cm, ex_adsl)
+
+    medlow <- c("AGE", "young", "BMRKR2", "HIGH")
+    cpth <- c("ARM", "C: Combination")
+    getvals <- function(tt) {
+        sapply(ctnames,
+               function(pth) {
+            unname(unlist(cell_values(tt, c("AGE", pth, "BMRKR2", "HIGH"), cpth)))
+        })
+    }
+    expect_identical(getvals(tbl2cm),
+                     cumsum(getvals(tbl2)))
+ # split_cols_by_quartiles
+
+    l3 <- basic_table() %>%
+        split_cols_by("ARM") %>%
+        split_cols_by_cutfun("AGE") %>% ##(quartiles("AGE", split_label = "Age") %>%
+        analyze("BMRKR2") %>%
+        append_topleft("counts")
+
+    tbl3 <- build_table(l3, ex_adsl)
+
+    l3b <-  basic_table() %>%
+        split_cols_by("ARM") %>%
+        split_cols_by_cuts("AGE", cuts = rtables:::qtile_cuts(ex_adsl$AGE)) %>% ##(quartiles("AGE", split_label = "Age") %>%
+        analyze("BMRKR2") %>%
+        append_topleft("counts")
+
+    tbl3b <- build_table(l3b, ex_adsl)
+
+    expect_identical(tbl3, tbl3b)
+
+    l3c <-  basic_table() %>%
+        split_cols_by("ARM") %>%
+        split_cols_by_quartiles("AGE") %>%
+        analyze("BMRKR2") %>%
+        append_topleft("counts")
+
+    tbl3c <- build_table(l3c, ex_adsl)
+
+    expect_identical(unname(unlist(cell_values(tbl3))),
+                     unname(unlist(cell_values(tbl3c))))
+
+
+    l3c_cm <-  basic_table() %>%
+        split_cols_by("ARM") %>%
+        split_cols_by_quartiles("AGE", cumulative = TRUE) %>%
+        analyze("BMRKR2") %>%
+        append_topleft("counts")
+
+    tbl3c_cm <- build_table(l3c_cm, ex_adsl)
+ # split_rows_by_quartiles
+ l4 <- basic_table() %>%
+     split_cols_by("ARM") %>%
+     add_colcounts() %>%
+     split_rows_by_quartiles("AGE", split_label = "Age") %>%
+     analyze("BMRKR2") %>%
+     append_topleft(c("Age Quartiles", " Counts BMRKR2"))
+
+ tbl4 <- build_table(l4, ex_adsl)
+
+
+    cvs4 <- unlist(cell_values(tbl4))
+
+    valslst4 <- unlist(lapply(1:3, function(i) lapply(cvs4, function(lst) lst[i])))
+
+    names(valslst4) <- gsub("^(.*)\\.BMRKR2\\.(.*)$", "\\2.\\1", names(valslst4))
+    valslst3 <- unlist(cell_values(tbl3c))
+    expect_identical(valslst3,
+                     valslst4[names(valslst3)])
+
+    l4cm <- basic_table() %>%
+        split_cols_by("ARM") %>%
+        add_colcounts() %>%
+        split_rows_by_quartiles("AGE", split_label = "Age", cumulative = TRUE) %>%
+        analyze("BMRKR2") %>%
+        append_topleft(c("Age Cumulative Quartiles", " Counts BMRKR2"))
+    tbl4cm <- build_table(l4cm, ex_adsl)
+
+
+    cvs4cm <- unlist(cell_values(tbl4cm))
+
+    valslst4cm <- unlist(lapply(1:3, function(i) lapply(cvs4cm, function(lst) lst[i])))
+
+    names(valslst4cm) <- gsub("^(.*)\\.BMRKR2\\.(.*)$", "\\2.\\1", names(valslst4cm))
+    valslst3cm <- unlist(cell_values(tbl3c_cm))
+    expect_identical(valslst3cm,
+                     valslst4cm[names(valslst3cm)])
 
 
-    expect_warning(lyt11 <- split_cols_by(lyt = NULL,"ARM"), "deprecated")
-    expect_identical(lyt11, basic_table() %>% split_cols_by("ARM"))
-    expect_warning(lyt22 <- split_rows_by(lyt = NULL,"ARM"), "deprecated")
-    expect_identical(lyt22, basic_table() %>% split_rows_by("ARM"))
 })
